@@ -520,55 +520,62 @@ if (isset($table_name) && ($table_name != ""))
 	// Get last inserted id for possible use by other modules.
 	if ($verb == "INSERT INTO")
 		$last_id = $bwb_dbh->lastInsertId();
-	else
-		$last_id = $where_key;
+	else	{
+		$query = "SELECT * FROM " . $table_name . " WHERE `" . $where_key . "`='" . $_POST[$where_key] . "'";
+		$result = $bwb_dbh->query($query);
+		$row = $result->fetch(PDO::FETCH_ASSOC);
+		$last_id = $row["id"];
+	}
 	
 
 	/////////////////////////////////////////////
 	// If table is user table for page access, then see if need to activate right now.
-	$query = "SELECT option_value FROM `" . BWB_TABLE_PREFIX . "options_selected` WHERE option_name='ActivateNewUsersAutomatically'";
-	$result = $bwb_dbh->query($query);
-	$row = $result->fetch(PDO::FETCH_ASSOC);
-	$activate = $row['option_value'];
-
-	if ($activate == 1)
+	if ($verb != "UPDATE")
 	{
-		$got_active = false;
-		$got_session = false;
-		$got_ip = false;
-		$got_userid = false;
-		$got_password = false;
-		$query ="SHOW COLUMNS FROM $bwb_database.$table_name";
+		$query = "SELECT option_value FROM `" . BWB_TABLE_PREFIX . "options_selected` WHERE option_name='ActivateNewUsersAutomatically'";
 		$result = $bwb_dbh->query($query);
-		while ($row = $result->fetch(PDO::FETCH_ASSOC))
+		$row = $result->fetch(PDO::FETCH_ASSOC);
+		$activate = $row['option_value'];
+	
+		if ($activate == 1)
 		{
-			if (($row['field'] == "Active") || ($row['Field'] == "Active"))
-				$got_active = true;
-			if (($row['field'] == "Session") || ($row['Field'] == "Session"))
-				$got_session = true;
-			if (($row['field'] == "IP") || ($row['Field'] == "IP"))
-				$got_ip = true;
-			if (($row['field'] == "UserID") || ($row['field'] == "userid") || ($row['Field'] == "UserID") || ($row['Field'] == "userid"))
-				$got_userid = true;
-			if (($row['field'] == "password") || ($row['Field'] == "password"))
-				$got_password = true;
-		}
-		if ($got_active && $got_session && $got_ip && $got_userid && $got_password)
-		{
-			$query = "UPDATE `$table_name` SET `Active`=1 WHERE id=$last_id";
-			$cnt = $bwb_dbh->exec($query);
-			
-			// Account activated, now go ahead and log in.
-			session_start();
-			if (isset($_POST['UserID']))
-				$userid = $_POST['UserID'];
-			elseif (isset($_POST['userid']))
-				$userid = $_POST['userid'];
-			$_SESSION['pub_userid'] = $userid;
-			$session = md5(session_id());
-			$ip = $_SERVER['REMOTE_ADDR'];
-			$query = "UPDATE `" . $table_name . "` SET `Session`='$session', `IP`='$ip' WHERE `UserID` = '$userid'";
-			$cnt = $bwb_dbh->exec($query);
+			$got_active = false;
+			$got_session = false;
+			$got_ip = false;
+			$got_userid = false;
+			$got_password = false;
+			$query ="SHOW COLUMNS FROM $bwb_database.$table_name";
+			$result = $bwb_dbh->query($query);
+			while ($row = $result->fetch(PDO::FETCH_ASSOC))
+			{
+				if (($row['field'] == "Active") || ($row['Field'] == "Active"))
+					$got_active = true;
+				if (($row['field'] == "Session") || ($row['Field'] == "Session"))
+					$got_session = true;
+				if (($row['field'] == "IP") || ($row['Field'] == "IP"))
+					$got_ip = true;
+				if (($row['field'] == "UserID") || ($row['field'] == "userid") || ($row['Field'] == "UserID") || ($row['Field'] == "userid"))
+					$got_userid = true;
+				if (($row['field'] == "password") || ($row['Field'] == "password"))
+					$got_password = true;
+			}
+			if ($got_active && $got_session && $got_ip && $got_userid && $got_password)
+			{
+				$query = "UPDATE `$table_name` SET `Active`=1 WHERE id=$last_id";
+				$cnt = $bwb_dbh->exec($query);
+				
+				// Account activated, now go ahead and log in.
+				session_start();
+				if (isset($_POST['UserID']))
+					$userid = $_POST['UserID'];
+				elseif (isset($_POST['userid']))
+					$userid = $_POST['userid'];
+				$_SESSION['pub_userid'] = $userid;
+				$session = md5(session_id());
+				$ip = $_SERVER['REMOTE_ADDR'];
+				$query = "UPDATE `" . $table_name . "` SET `Session`='$session', `IP`='$ip' WHERE `UserID` = '$userid'";
+				$cnt = $bwb_dbh->exec($query);
+			}
 		}
 	}
 	/////////////////////////////////////////////
