@@ -29,6 +29,8 @@
 // Added thumbnail checking with switch to actual image if no thumb.
 // Revised: 12/30/2014	ELL
 // Added browser CSS reset button.
+// Revised: 1/12/2015	ELL
+// Replaced deprecated font-stretch with letter-spacing.
 
 
 var param_array = {'popup_msg_type' : 1, 'status_msg' : '', 'popup_timeout' : -1};
@@ -60,7 +62,8 @@ function enable_disable_controls(ShowMessage)
 		document.getElementById("vertical_align").disabled = false;
 		document.getElementById("display").disabled = false;
 		document.getElementById("weight").disabled = false;
-		document.getElementById("font_stretch").disabled = false;
+		//document.getElementById("font_stretch").disabled = false;
+		document.getElementById("letter_spacing_units").disabled = false;
 		document.getElementById("italic").disabled = false;
 		document.getElementById("underline").disabled = false;
 		document.getElementById("overline").disabled = false;
@@ -70,7 +73,7 @@ function enable_disable_controls(ShowMessage)
 		document.getElementById("small_caps").disabled = false;
 		document.getElementById("no_text_decoration").disabled = false;
 		document.getElementById("shadow").disabled = false;
-		document.getElementById("line_height").disabled = false;
+		//document.getElementById("line_height").disabled = false;
 		document.getElementById("line_height_units").disabled = false;
 		
 		document.getElementById("bkgd_color").disabled = false;
@@ -163,6 +166,8 @@ function enable_disable_controls(ShowMessage)
 		margin_auto_clicked("right");
 		enable_disable_background_positions();
 		enable_disable_background_sizes();
+		enable_disable_letter_spacing();
+		enable_disable_line_height();
 		
 		document.getElementById("text_table").style.backgroundColor = "#FFCCCC";
 		document.getElementById("background_table").style.backgroundColor = "#CCFFCC";
@@ -184,7 +189,9 @@ function enable_disable_controls(ShowMessage)
 		document.getElementById("vertical_align").disabled = true;
 		document.getElementById("display").disabled = true;
 		document.getElementById("weight").disabled = true;
-		document.getElementById("font_stretch").disabled = true;
+		//document.getElementById("font_stretch").disabled = true;
+		document.getElementById("letter_spacing").disabled = true;
+		document.getElementById("letter_spacing_units").disabled = true;
 		document.getElementById("italic").disabled = true;
 		document.getElementById("underline").disabled = true;
 		document.getElementById("overline").disabled = true;
@@ -401,6 +408,22 @@ function enable_disable_background_sizes()
 	}
 }
 
+function enable_disable_letter_spacing()
+{
+	if (document.getElementById("letter_spacing_units").value == 1)
+		document.getElementById("letter_spacing").disabled = false;
+	else
+		document.getElementById("letter_spacing").disabled = true;
+}
+
+function enable_disable_line_height()
+{
+	if ((document.getElementById("line_height_units").value < 1) || (document.getElementById("line_height_units").value > 3))
+		document.getElementById("line_height").disabled = true;
+	else
+		document.getElementById("line_height").disabled = false;
+}
+
 //////////////////////////////////////////////////////////////////////////////////////
 function UpdateMessage(xmlhttp)
 {
@@ -704,19 +727,44 @@ function CheckBorderParams(element)
 	}
 }
 
-function CheckLineHeight(element)
+function CheckLetterSpacing(element)
 {
-	if (((element.value == 0) || (element.value == 4)) && (document.getElementById('line_height').value != -1) && (document.getElementById('line_height').value != '-not set-') && (document.getElementById('line_height').value != ''))
+	if (((element.value != 1) && (element.value != -1)) && (document.getElementById('letter_spacing').value != -1000000) && (document.getElementById('letter_spacing').value != '-not set-') && (document.getElementById('letter_spacing').value != ''))
 	{
 		popup_msg.popup_msg_type = 2;
-			popup_msg.status_msg = "You have selected <b>Normal</b> or <b>Inherit</b> for your line height, yet you have a positive number set for line height. Note that the number you have selected will be ignored.  If you want to set a line height, choose <b>Bultiplyer</b>, <b>%</b> or <b>px</b> instead.";
-			popup_msg.popup_timeout = -1;
-			popup_msg.top_offset = 0;
-			popup_msg.left_offset = 250;
-			popup_msg.msg_width = 600;
-			popup_msg.popup_timeout = 10000;
-			popup_msg.ShowPopupMsg();
+		popup_msg.status_msg = "You have selected <b>Normal</b>, <b>Initial</b> or <b>Inherit</b> for your letter spacing, yet you have a number set for letter spacing. Note that the number you have selected will be ignored.  If you want to set a letter spacing, choose <b>px</b> instead.";
+		popup_msg.popup_timeout = -1;
+		popup_msg.top_offset = 0;
+		popup_msg.left_offset = 250;
+		popup_msg.msg_width = 600;
+		popup_msg.popup_timeout = 10000;
+		popup_msg.ShowPopupMsg();
 	}
+	
+	if (element.value == 1)
+		document.getElementById("letter_spacing").disabled = false;
+	else
+		document.getElementById("letter_spacing").disabled = true;
+}
+
+function CheckLineHeight(element)
+{
+	if (((element.value == 0) || (element.value > 3)) && (document.getElementById('line_height').value != -1) && (document.getElementById('line_height').value != '-not set-') && (document.getElementById('line_height').value != ''))
+	{
+		popup_msg.popup_msg_type = 2;
+		popup_msg.status_msg = "You have selected <b>Normal</b> or <b>Inherit</b> for your line height, yet you have a positive number set for line height. Note that the number you have selected will be ignored.  If you want to set a line height, choose <b>Bultiplyer</b>, <b>%</b> or <b>px</b> instead.";
+		popup_msg.popup_timeout = -1;
+		popup_msg.top_offset = 0;
+		popup_msg.left_offset = 250;
+		popup_msg.msg_width = 600;
+		popup_msg.popup_timeout = 10000;
+		popup_msg.ShowPopupMsg();
+	}
+	
+	if ((element.value < 1) || (element.value > 3))
+		document.getElementById("line_height").disabled = true;
+	else
+		document.getElementById("line_height").disabled = false;
 }
 
 ////////////////////////////////////////////////////////////////////////////
