@@ -17,6 +17,8 @@
 // Added ability to present plugin buttons to bloggers and restricted users if plugin access set to blogger or restricted.
 // Revised: 11/17/2014	ELL
 // Added new button for editing files.
+// Revised 1/12/2015	ELL
+// Added code to hide/show new NEW SESSION button. Fixed bug with sliver of LOGOUT button showing with collapsed header.
 // 
 // 
 var browser = BrowserDetect.browser;
@@ -605,6 +607,9 @@ function AnimateCollapseHeader()
 	{
 		document.getElementById("logo_div").style.display = "none";
 		document.getElementById("help_button").style.display = "none";
+		document.getElementById("btn_logout").style.display = "none";
+		if ((access_level == "power_user") || (access_level == "admin"))
+			document.getElementById("btn_new_session").style.display = "none";
 	}
 	
 	curr_height6--;
@@ -645,6 +650,9 @@ function AnimateExpandHeader()
 	{
 		document.getElementById("logo_div").style.display = inherit;
 		document.getElementById("help_button").style.display = inherit;
+		document.getElementById("btn_logout").style.display = inherit;
+		if ((access_level == "power_user") || (access_level == "admin"))
+			document.getElementById("btn_new_session").style.display = inherit;
 	}
 
 	curr_height6++;
