@@ -931,4 +931,16 @@ function PopulateUser(data)
 		document.getElementById("first_name_edit").value = JSON_row.first_name;
 		document.getElementById("last_name_edit").value = JSON_row.last_name;
 	}
+}
+
+///////////////////////////////////////////////////////////////////////////////////////////////////////////
+function ResizeWorkspace(mainWidth, mainHeight, menuWidth, headerHeight) {
+
+}
+
+function DisplayNotSavedMessage(btn)	{
+	// Needed to complete call when deleting unsaved page.
+	window.parent.SetWorkSavedNotSaved(true);
+	window.parent.next_btn = btn;
+	window.parent.DoNextClick();
 }
\ No newline at end of file
