@@ -28,6 +28,8 @@
 // Fixed bug with center site button and sticky footers button that got broke when submit_action was implemented inplace of the submit button.
 // Revised: 3/5/2014	ELL
 // Removed obsolete image Upload as this in now done with "AJAX" image uploader.
+// Revised: 1/12/2015	ELL
+// Replaced deprecated font-stretch with letter-spacing.
 //
 //
 	include ("check_session.php");
@@ -81,7 +83,9 @@
 			$overline = $row["overline"];
 			$blink = $row["blink"];
 			$linethrough = $row["linethrough"];
-			$font_stretch = $row["font_stretch"];
+			//$font_stretch = $row["font_stretch"];
+			$letter_spacing = $row["letter_spacing"];
+			$letter_spacing_units = $row["letter_spacing_units"];
 			$oblique = $row["oblique"];
 			$small_caps = $row["small_caps"];
 			$no_text_decoration = $row["no_text_decoration"];
@@ -190,7 +194,7 @@
 		$insert_key = "class='" . $class . "', ";
 		
 		$query2 = BuildSQLString(BWB_TABLE_PREFIX . $site_css_table, "INSERT INTO", "", $insert_key, $use_table_data, $font, $font2, $font3, $font_size, $text_color, $padding_top, $padding_right, $padding_bottom, $padding_left, $weight, $italic,
-		$underline, $overline, $blink, $linethrough, $font_stretch, $oblique, $small_caps, $no_text_decoration, $shadow, $shadow_color, $shadow_x_offset,
+		$underline, $overline, $blink, $linethrough, $letter_spacing, $letter_spacing_units, $oblique, $small_caps, $no_text_decoration, $shadow, $shadow_color, $shadow_x_offset,
 		$shadow_y_offset, $shadow_blur, $line_height, $line_height_units, $align, $vertical_align, $bkgd_color, $bkgd_opacity, $border, $border_color,
 		$border_style, $outline_style, $border_collapse, $border_sides, $margin_top, $margin_top_units, $margin_top_auto, $margin_right, $margin_right_units,
 		$margin_right_auto, $margin_left, $margin_left_units, $margin_left_auto, $margin_bottom, $margin_bottom_units, $margin_bottom_auto,
@@ -244,8 +248,12 @@
 	else $blink = 0;
 	if ($_POST["linethrough"]) $linethrough = $_POST["linethrough"];
 	else $linethrough = 0;
-	if ($_POST["font_stretch"]) $font_stretch = $_POST["font_stretch"];
-	else $font_stretch = "-not selected-";
+//	if ($_POST["font_stretch"]) $font_stretch = $_POST["font_stretch"];
+//	else $font_stretch = "-not selected-";
+	if (is_numeric($_POST["letter_spacing"])) $letter_spacing = $_POST["letter_spacing"];
+	else $letter_spacing = -1000000;
+	if (is_numeric($_POST["letter_spacing_units"])) $letter_spacing_units = $_POST["letter_spacing_units"];
+	else $letter_spacing_units = -1;
 	if ($_POST["oblique"]) $oblique = $_POST["oblique"];
 	else $oblique = 0;
 	if ($_POST["small_caps"]) $small_caps = $_POST["small_caps"];
@@ -264,8 +272,8 @@
 	else $shadow_blur = 0;
 	if (is_numeric($_POST["line_height"])) $line_height = $_POST["line_height"];
 	else $line_height = -1;
-	if ($_POST["line_height_units"]) $line_height_units = $_POST["line_height_units"];
-	else $line_height_units = 0;
+	if (is_numeric($_POST["line_height_units"])) $line_height_units = $_POST["line_height_units"];
+	else $line_height_units = -1;
 	
 	if ($_POST["align"]) $align = $_POST["align"];
 	else $align = "-not selected-";
@@ -467,7 +475,7 @@
 		$condition = "`class` = '" . $class . "'";
 		
 		$query = BuildSQLString(BWB_TABLE_PREFIX . $site_css_table, "UPDATE", $condition, "", $use_table_data, $font, $font2, $font3, $font_size, $text_color, $padding_top, $padding_right, $padding_bottom, $padding_left, $weight, $italic,
-		$underline, $overline, $blink, $linethrough, $font_stretch, $oblique, $small_caps, $no_text_decoration, $shadow, $shadow_color, $shadow_x_offset,
+		$underline, $overline, $blink, $linethrough, $letter_spacing, $letter_spacing_units, $oblique, $small_caps, $no_text_decoration, $shadow, $shadow_color, $shadow_x_offset,
 		$shadow_y_offset, $shadow_blur, $line_height, $line_height_units, $align, $vertical_align, $bkgd_color, $bkgd_opacity, $border, $border_color,
 		$border_style, $outline_style, $border_collapse, $border_sides, $margin_top, $margin_top_units, $margin_top_auto, $margin_right, $margin_right_units,
 		$margin_right_auto, $margin_left, $margin_left_units, $margin_left_auto, $margin_bottom, $margin_bottom_units, $margin_bottom_auto,
@@ -486,7 +494,7 @@
 		$insert_key = "class='" . $class . "', ";
 		
 		 $query = BuildSQLString(BWB_TABLE_PREFIX . $site_css_table, "INSERT INTO", "", $insert_key, $use_table_data, $font, $font2, $font3, $font_size, $text_color, $padding_top, $padding_right, $padding_bottom, $padding_left, $weight, $italic,
-		$underline, $overline, $blink, $linethrough, $font_stretch, $oblique, $small_caps, $no_text_decoration, $shadow, $shadow_color, $shadow_x_offset,
+		$underline, $overline, $blink, $linethrough, $letter_spacing, $letter_spacing_units, $oblique, $small_caps, $no_text_decoration, $shadow, $shadow_color, $shadow_x_offset,
 		$shadow_y_offset, $shadow_blur, $line_height, $line_height_units, $align, $vertical_align, $bkgd_color, $bkgd_opacity, $border, $border_color,
 		$border_style, $outline_style, $border_collapse, $border_sides, $margin_top, $margin_top_units, $margin_top_auto, $margin_right, $margin_right_units,
 		$margin_right_auto, $margin_left, $margin_left_units, $margin_left_auto, $margin_bottom, $margin_bottom_units, $margin_bottom_auto,
